==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-knownerror-mgmt/dictionaries/de.dict.itop-knownerror-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author ITOMIG GmbH <martin.raenker@itomig.de>
 *
 */
Dict::Add('DE DE', 'German', 'Deutsch', [
	'Class:KnownError' => 'Known Error',
	'Class:KnownError+' => 'Dokumentierter Fehler für ein Problem',
	'Class:KnownError/Attribute:ci_list' => 'CIs',
	'Class:KnownError/Attribute:ci_list+' => 'Alle CIs, die mit diesem Known Error verknüpft sind',
	'Class:KnownError/Attribute:cust_name' => 'Kundenname',
	'Class:KnownError/Attribute:cust_name+' => '',
	'Class:KnownError/Attribute:document_list' => 'Dokumente',
	'Class:KnownError/Attribute:document_list+' => 'Alle Dokumente, die mit diesem Known Error verknüpft sind',
	'Class:KnownError/Attribute:domain' => 'Bereich',
	'Class:KnownError/Attribute:domain+' => '',
	'Class:KnownError/Attribute:domain/Value:Application' => 'Anwendung',
	'Class:KnownError/Attribute:domain/Value:Application+' => 'Anwendung',
	'Class:KnownError/Attribute:domain/Value:Desktop' => 'Desktop',
	'Class:KnownError/Attribute:domain/Value:Desktop+' => 'Desktop',
	'Class:KnownError/Attribute:domain/Value:Network' => 'Netzwerk',
	'Class:KnownError/Attribute:domain/Value:Network+' => 'Netzwerk',
	'Class:KnownError/Attribute:domain/Value:Server' => 'Server',
	'Class:KnownError/Attribute:domain/Value:Server+' => 'Server',
	'Class:KnownError/Attribute:error_code' => 'Fehlercode',
	'Class:KnownError/Attribute:error_code+' => '',
	'Class:KnownError/Attribute:model' => 'Modell',
	'Class:KnownError/Attribute:model+' => '',
	'Class:KnownError/Attribute:name' => 'Name',
	'Class:KnownError/Attribute:name+' => '',
	'Class:KnownError/Attribute:org_id' => 'Kunde',
	'Class:KnownError/Attribute:org_id+' => '',
	'Class:KnownError/Attribute:problem_id' => 'Zugehöriges Problem',
	'Class:KnownError/Attribute:problem_id+' => '',
	'Class:KnownError/Attribute:problem_ref' => 'Referenz',
	'Class:KnownError/Attribute:problem_ref+' => '',
	'Class:KnownError/Attribute:root_cause' => 'Grundursache',
	'Class:KnownError/Attribute:root_cause+' => '',
	'Class:KnownError/Attribute:solution' => 'Lösung',
	'Class:KnownError/Attribute:solution+' => '',
	'Class:KnownError/Attribute:symptom' => 'Symptom',
	'Class:KnownError/Attribute:symptom+' => '',
	'Class:KnownError/Attribute:vendor' => 'Anbieter',
	'Class:KnownError/Attribute:vendor+' => '',
	'Class:KnownError/Attribute:version' => 'Version',
	'Class:KnownError/Attribute:version+' => '',
	'Class:KnownError/Attribute:workaround' => 'Workaround',
	'Class:KnownError/Attribute:workaround+' => '',
	'Class:lnkDocumentToError' => 'Verknüpfung Dokumente/KnownError',
	'Class:lnkDocumentToError+' => '',
	'Class:lnkDocumentToError/Attribute:document_id' => 'Dokument',
	'Class:lnkDocumentToError/Attribute:document_id+' => '',
	'Class:lnkDocumentToError/Attribute:document_name' => 'Dokumentname',
	'Class:lnkDocumentToError/Attribute:document_name+' => '',
	'Class:lnkDocumentToError/Attribute:error_id' => 'Known Error',
	'Class:lnkDocumentToError/Attribute:error_id+' => '',
	'Class:lnkDocumentToError/Attribute:error_name' => 'Known Error-Name',
	'Class:lnkDocumentToError/Attribute:error_name+' => '',
	'Class:lnkDocumentToError/Attribute:link_type' => 'Verknüpfungstyp',
	'Class:lnkDocumentToError/Attribute:link_type+' => '',
	'Class:lnkDocumentToError/Name' => '%1$s / %2$s',
	'Class:lnkErrorToFunctionalCI' => 'Verknüpfung KnownError/FunctionalCI',
	'Class:lnkErrorToFunctionalCI+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id' => 'Fehler',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name' => 'Known Error-Name',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id' => 'CI',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name' => 'CI-Name',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:reason' => 'Begründung',
	'Class:lnkErrorToFunctionalCI/Attribute:reason+' => '',
	'Class:lnkErrorToFunctionalCI/Name' => '%1$s / %2$s',
	'Menu:NewError' => 'Neuer Known Error',
	'Menu:NewError+' => 'Neuen Known Error dokumentieren',
	'Menu:Problem:KnownErrors' => 'Alle Known Errors',
	'Menu:Problem:KnownErrors+' => 'Alle Known Errors',
	'Menu:Problem:Shortcuts' => 'Shortcuts',
	'Menu:ProblemManagement' => 'Problem Management',
	'Menu:ProblemManagement+' => 'Problem Management',
	'Menu:SearchError' => 'Nach Known Error suchen',
	'Menu:SearchError+' => 'Nach dokumentierten Fehlern suchen',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-knownerror-mgmt/dictionaries/de.dict.itop-knownerror-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author ITOMIG GmbH <martin.raenker@itomig.de>
 *
 */
Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:KnownError' => 'Known Error',
	'Class:KnownError+' => 'Dokumentierter Fehler für ein Problem',
	'Class:KnownError/Attribute:name' => 'Name',
	'Class:KnownError/Attribute:name+' => '',
	'Class:KnownError/Attribute:org_id' => 'Kunde',
	'Class:KnownError/Attribute:org_id+' => '',
	'Class:KnownError/Attribute:cust_name' => 'Kundenname',
	'Class:KnownError/Attribute:cust_name+' => '',
	'Class:KnownError/Attribute:problem_id' => 'Zugehöriges Problem',
	'Class:KnownError/Attribute:problem_id+' => '',
	'Class:KnownError/Attribute:problem_ref' => 'Referenz',
	'Class:KnownError/Attribute:problem_ref+' => '',
	'Class:KnownError/Attribute:symptom' => 'Symptom',
	'Class:KnownError/Attribute:symptom+' => '',
	'Class:KnownError/Attribute:root_cause' => 'Grundursache',
	'Class:KnownError/Attribute:root_cause+' => '',
	'Class:KnownError/Attribute:workaround' => 'Workaround',
	'Class:KnownError/Attribute:workaround+' => '',
	'Class:KnownError/Attribute:solution' => 'Lösung',
	'Class:KnownError/Attribute:solution+' => '',
	'Class:KnownError/Attribute:error_code' => 'Fehlercode',
	'Class:KnownError/Attribute:error_code+' => '',
	'Class:KnownError/Attribute:domain' => 'Bereich',
	'Class:KnownError/Attribute:domain+' => '',
	'Class:KnownError/Attribute:domain/Value:Application' => 'Anwendung',
	'Class:KnownError/Attribute:domain/Value:Application+' => 'Anwendung',
	'Class:KnownError/Attribute:domain/Value:Desktop' => 'Desktop',
	'Class:KnownError/Attribute:domain/Value:Desktop+' => 'Desktop',
	'Class:KnownError/Attribute:domain/Value:Network' => 'Netzwerk',
	'Class:KnownError/Attribute:domain/Value:Network+' => 'Netzwerk',
	'Class:KnownError/Attribute:domain/Value:Server' => 'Server',
	'Class:KnownError/Attribute:domain/Value:Server+' => 'Server',
	'Class:KnownError/Attribute:vendor' => 'Anbieter',
	'Class:KnownError/Attribute:vendor+' => '',
	'Class:KnownError/Attribute:model' => 'Modell',
	'Class:KnownError/Attribute:model+' => '',
	'Class:KnownError/Attribute:version' => 'Version',
	'Class:KnownError/Attribute:version+' => '',
	'Class:KnownError/Attribute:ci_list' => 'CIs',
	'Class:KnownError/Attribute:ci_list+' => 'Alle CIs, die mit diesem Known Error verknüpft sind',
	'Class:KnownError/Attribute:document_list' => 'Dokumente',
	'Class:KnownError/Attribute:document_list+' => 'Alle Dokumente, die mit diesem Known Error verknüpft sind',
));

//
// Class: lnkErrorToFunctionalCI
//

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:lnkErrorToFunctionalCI' => 'Verknüpfung KnownError/FunctionalCI',
	'Class:lnkErrorToFunctionalCI+' => '',
	'Class:lnkErrorToFunctionalCI/Name' => '%1$s / %2$s',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id' => 'CI',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name' => 'CI-Name',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id' => 'Fehler',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name' => 'Known Error-Name',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name+' => '',
	'Class:lnkErrorToFunctionalCI/Attribute:reason' => 'Begründung',
	'Class:lnkErrorToFunctionalCI/Attribute:reason+' => '',
));

//
// Class: lnkDocumentToError
//

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:lnkDocumentToError' => 'Verknüpfung Dokumente/KnownError',
	'Class:lnkDocumentToError+' => '',
	'Class:lnkDocumentToError/Name' => '%1$s / %2$s',
	'Class:lnkDocumentToError/Attribute:document_id' => 'Dokument',
	'Class:lnkDocumentToError/Attribute:document_id+' => '',
	'Class:lnkDocumentToError/Attribute:document_name' => 'Dokumentname',
	'Class:lnkDocumentToError/Attribute:document_name+' => '',
	'Class:lnkDocumentToError/Attribute:error_id' => 'Known Error',
	'Class:lnkDocumentToError/Attribute:error_id+' => '',
	'Class:lnkDocumentToError/Attribute:error_name' => 'Known Error-Name',
	'Class:lnkDocumentToError/Attribute:error_name+' => '',
	'Class:lnkDocumentToError/Attribute:link_type' => 'Verknüpfungstyp',
	'Class:lnkDocumentToError/Attribute:link_type+' => '',
));

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Menu:ProblemManagement' => 'Problem Management',
	'Menu:ProblemManagement+' => 'Problem Management',
	'Menu:Problem:Shortcuts' => 'Shortcuts',
	'Menu:NewError' => 'Neuer Known Error',
	'Menu:NewError+' => 'Neuen Known Error dokumentieren',
	'Menu:SearchError' => 'Nach Known Error suchen',
	'Menu:SearchError+' => 'Nach dokumentierten Fehlern suchen',
	'Menu:Problem:KnownErrors' => 'Alle Known Errors',
	'Menu:Problem:KnownErrors+' => 'Alle Known Errors',
));
